==> hdf4_handler-3.7.8.tar.gz: hdf4_handler-3.7.8/hdfclass/hcerr.cc <==
// This file is part of the hdf4 data handler for the OPeNDAP data server.

// Copyright (c) 2005 OPeNDAP, Inc.
// Author: James Gallagher <jgallagher@opendap.org>
//
// This is free software; you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the Free
// Software Foundation; either version 2.1 of the License, or (at your
// option) any later version.
// 
// This software is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
// or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
// License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with this software; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
// You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.

//////////////////////////////////////////////////////////////////////////////
// Copyright 1996, by the California Institute of Technology.
// ALL RIGHTS RESERVED. United States Government Sponsorship
// acknowledged. Any commercial use must be negotiated with the
// Office of Technology Transfer at the California Institute of
// Technology. This software may be subject to U.S. export control
// laws and regulations. By accepting this software, the user
// agrees to comply with all applicable U.S. export laws and
// regulations. User has the responsibility to obtain export
// licenses, or other export authority as may be required before
// exporting such information to foreign countries or providing
// access to foreign persons.

// U.S. Government Sponsorship under NASA Contract
// NAS7-1260 is acknowledged.
// 
// Author: Todd.K.Karakashian@jpl.nasa.gov
//
// $RCSfile: hcerr.cc,v $ - implementation of hcerr class
// 
//////////////////////////////////////////////////////////////////////////////

#include "config_hdf.h"

#include <hdf.h>
#ifdef __POWERPC__
#undef isascii
#endif

#include <sstream>

using std::ostringstream;
using std::endl;

#include "hcerr.h"
#include "cgi_util.h"

hcerr::hcerr(const char *msg, const char *file, int line)
:  Error(msg)
{
    ostringstream strm;
    strm << get_error_message() << endl
        << "Location: \"" << file << "\", line " << line << endl;
    for (int i = 0; i < 5; ++i)
        strm << i << ") " << HEstring((hdf_err_code_t) HEvalue(i)) << endl;
    ErrMsgT(strm.str());
}

==> hdf4_handler-3.8.1.tar.gz: hdf4_handler-3.8.1/hdfclass/hcerr.cc <==
// This file is part of the hdf4 data handler for the OPeNDAP data server.

// Copyright (c) 2005 OPeNDAP, Inc.
// Author: James Gallagher <jgallagher@opendap.org>
//
// This is free software; you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the Free
// Software Foundation; either version 2.1 of the License, or (at your
// option) any later version.
// 
// This software is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
// or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
// License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with this software; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
// You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.

//////////////////////////////////////////////////////////////////////////////
// Copyright 1996, by the California Institute of Technology.
// ALL RIGHTS RESERVED. United States Government Sponsorship
// acknowledged. Any commercial use must be negotiated with the
// Office of Technology Transfer at the California Institute of
// Technology. This software may be subject to U.S. export control
// laws and regulations. By accepting this software, the user
// agrees to comply with all applicable U.S. export laws and
// regulations. User has the responsibility to obtain export
// licenses, or other export authority as may be required before
// exporting such information to foreign countries or providing
// access to foreign persons.

// U.S. Government Sponsorship under NASA Contract
// NAS7-1260 is acknowledged.
// 
// Author: Todd.K.Karakashian@jpl.nasa.gov
//
// $RCSfile: hcerr.cc,v $ - implementation of hcerr class
// 
//////////////////////////////////////////////////////////////////////////////

#include "config_hdf.h"

#include <hdf.h>
#ifdef __POWERPC__
#undef isascii
#endif

#include <sstream>

using std::ostringstream;
using std::endl;

#include <BESLog.h>

#include "hcerr.h"

hcerr::hcerr(const char *msg, const char *file, int line)
:  Error(msg)
{
    ostringstream strm;
    strm << get_error_message() << endl
        << "Location: \"" << file << "\", line " << line << endl;
    for (int i = 0; i < 5; ++i)
        strm << i << ") " << HEstring((hdf_err_code_t) HEvalue(i)) << endl;
    (*BESLog::TheLog()) << strm.str() << endl ;
}
